@@ -23,7 +23,7 @@ SOFTWARE.
 """
 
 from enum import Enum
-from typing import Union, Tuple
+from typing import Union, Tuple, Self
 
 from .constants import WIND_DIRECTION_EMOJIS
 
@@ -70,14 +70,14 @@ class HeatIndex(IndexedEnum):
   DANGER = None
   EXTREME_DANGER = None
 
-  def _new(celcius_index: int, true_index: int) -> 'HeatIndex':
+  def _new(celcius_index: int, true_index: int) -> Self:
     enum = HeatIndex(celcius_index)
     enum.index = true_index
 
     return enum
 
   @classmethod
-  def _missing_(self, celcius_index: int) -> 'HeatIndex':
+  def _missing_(self, celcius_index: int) -> Self:
     if celcius_index <= 32:
       return self.CAUTION
     elif celcius_index <= 39:
@@ -99,14 +99,14 @@ class UltraViolet(BasicEnum, IndexedEnum):
   VERY_HIGH = None
   EXTREME = None
 
-  def _new(index: int) -> 'UltraViolet':
+  def _new(index: int) -> Self:
     enum = UltraViolet(index)
     enum.index = index
 
     return enum
 
   @classmethod
-  def _missing_(self, index: int) -> 'UltraViolet':
+  def _missing_(self, index: int) -> Self:
     if index <= 2:
       return self.LOW
     elif index <= 5:
@@ -122,7 +122,7 @@ class UltraViolet(BasicEnum, IndexedEnum):
 class WindDirection(BasicEnum):
   """Represents a wind direction."""
 
-  __slots__: Tuple[str, ...] = ('__degrees',)
+  __slots__: Tuple[str, ...] = ('degrees',)
 
   NORTH = 'N'
   NORTH_NORTHEAST = 'NNE'
@@ -141,9 +141,12 @@ class WindDirection(BasicEnum):
   NORTHWEST = 'NW'
   NORTH_NORTHWEST = 'NNW'
 
-  def _new(value: str, degrees: float) -> 'WindDirection':
+  degrees: float
+  """The wind direction's value in degrees."""
+
+  def _new(value: str, degrees: float) -> Self:
     enum = WindDirection(value)
-    enum.__degrees = degrees
+    enum.degrees = degrees
 
     return enum
 
@@ -183,20 +186,17 @@ class WindDirection(BasicEnum):
     else:
       return 326.25 < other <= 348.75
 
+  def __int__(self) -> int:
+    return int(self.degrees)
+
   def __float__(self) -> float:
-    return self.__degrees
-
-  @property
-  def degrees(self) -> int:
-    """The wind direction's value in degrees."""
-
-    return self.__degrees
+    return self.degrees
 
   @property
   def emoji(self) -> str:
     """The emoji representing this enum."""
 
-    return WIND_DIRECTION_EMOJIS[int(((self.__degrees + 22.5) % 360) / 45.0)]
+    return WIND_DIRECTION_EMOJIS[int(((self.degrees + 22.5) % 360) / 45.0)]
 
 
 class Locale(Enum):
@@ -310,39 +310,30 @@ class Kind(BasicEnum):
   THUNDERY_SNOW_SHOWERS = 392
 
   @classmethod
-  def _missing_(self, value: int) -> 'Kind':
-    if value == 248 or value == 260:
+  def _missing_(self, value: int) -> Self:
+    if value in (248, 260):
       return self.FOG
-    elif value == 263 or value == 353:
+    elif value in (263, 353):
       return self.LIGHT_SHOWERS
-    elif value == 362 or value == 365 or value == 374:
+    elif value in (362, 365, 374):
       return self.LIGHT_SLEET_SHOWERS
-    elif (
-      value == 185
-      or value == 281
-      or value == 284
-      or value == 311
-      or value == 314
-      or value == 317
-      or value == 350
-      or value == 377
-    ):
+    elif value in (185, 281, 284, 311, 314, 317, 350, 377):
       return self.LIGHT_SLEET
     elif value == 386:
       return self.THUNDERY_SHOWERS
     elif value == 320:
       return self.LIGHT_SNOW
-    elif value == 329 or value == 332 or value == 338:
+    elif value in (329, 332, 338):
       return self.HEAVY_SNOW
-    elif value == 293 or value == 296:
+    elif value in (293, 296):
       return self.LIGHT_RAIN
-    elif value == 305 or value == 356:
+    elif value in (305, 356):
       return self.HEAVY_SHOWERS
-    elif value == 308 or value == 359:
+    elif value in (308, 359):
       return self.HEAVY_RAIN
-    elif value == 326 or value == 368:
+    elif value in (326, 368):
       return self.LIGHT_SNOW_SHOWERS
-    elif value == 371 or value == 395:
+    elif value in (371, 395):
       return self.HEAVY_SNOW_SHOWERS
 
   @property
